@@ -137,8 +137,8 @@ class PyXploraApi(PyXplora):
             "lat": watch_location.get("lat", None),
             "lng": watch_location.get("lng", None),
             "rad": watch_location.get("rad", -1),
-            "step": watch_location.get("step", 0),
-            "distance": watch_location.get("distance", -1),
+            "step": watch_location.get("watch_last_location", {}).get("step", 0),
+            "distance": watch_location.get("watch_last_location", {}).get("distance", -1),
             "isInSafeZone": isInSafeZone,
             "safeZoneLabel": safeZoneLabel,
             "getWatchSafeZones": watch_safe_zones,
